@@ -2,10 +2,9 @@ from __future__ import absolute_import
 
 import re
 
+from sqlalchemy import util
 from sqlalchemy.engine import default
 from sqlalchemy.testing.assertions import _expect_warnings
-from sqlalchemy.testing.assertions import assert_raises  # noqa
-from sqlalchemy.testing.assertions import assert_raises_message  # noqa
 from sqlalchemy.testing.assertions import eq_  # noqa
 from sqlalchemy.testing.assertions import is_  # noqa
 from sqlalchemy.testing.assertions import is_false  # noqa
@@ -14,9 +13,33 @@ from sqlalchemy.testing.assertions import is_true  # noqa
 from sqlalchemy.testing.assertions import ne_  # noqa
 from sqlalchemy.util import decorator
 
+from ..util import sqla_compat
 from ..util.compat import py3k
 
 
+def assert_raises(except_cls, callable_, *args, **kw):
+    try:
+        callable_(*args, **kw)
+        success = False
+    except except_cls:
+        success = True
+
+    # assert outside the block so it works for AssertionError too !
+    assert success, "Callable did not raise an exception"
+
+
+def assert_raises_message(except_cls, msg, callable_, *args, **kwargs):
+    try:
+        callable_(*args, **kwargs)
+        assert False, "Callable did not raise an exception"
+    except except_cls as e:
+        assert re.search(msg, util.text_type(e), re.UNICODE), "%r !~ %s" % (
+            msg,
+            e,
+        )
+        print(util.text_type(e).encode("utf-8"))
+
+
 def eq_ignore_whitespace(a, b, msg=None):
     # sqlalchemy.testing.assertion has this function
     # but not with the special "!U" detection part
@@ -43,14 +66,9 @@ def _get_dialect(name):
     if name is None or name == "default":
         return default.DefaultDialect()
     else:
-        try:
-            dialect_mod = _dialect_mods[name]
-        except KeyError:
-            dialect_mod = getattr(
-                __import__("sqlalchemy.dialects.%s" % name).dialects, name
-            )
-            _dialect_mods[name] = dialect_mod
-        d = dialect_mod.dialect()
+
+        d = sqla_compat._create_url(name).get_dialect()()
+
         if name == "postgresql":
             d.implicit_returning = True
         elif name == "mssql":
